@@ -63,6 +63,60 @@ test.describe('Notebook scroll on navigation (with windowing)', () => {
   }
 });
 
+test.describe('Notebook scroll on navigation (with windowing), named properties allowed', () => {
+  test.use({
+    mockSettings: {
+      ...galata.DEFAULT_SETTINGS,
+      '@jupyterlab/notebook-extension:tracker': {
+        ...galata.DEFAULT_SETTINGS['@jupyterlab/notebook-extension:tracker'],
+        windowingMode: 'full'
+      },
+      '@jupyterlab/apputils-extension:sanitizer': {
+        ...galata.DEFAULT_SETTINGS['@jupyterlab/apputils-extension:sanitizer'],
+        allowNamedProperties: true
+      }
+    }
+  });
+
+  test.beforeEach(async ({ page, tmpPath }) => {
+    await page.contents.uploadFile(
+      path.resolve(__dirname, `./notebooks/${fileName}`),
+      `${tmpPath}/${fileName}`
+    );
+
+    await page.notebook.openByPath(`${tmpPath}/${fileName}`);
+    await page.notebook.activate(fileName);
+  });
+
+  test.afterEach(async ({ page, tmpPath }) => {
+    await page.contents.deleteDirectory(tmpPath);
+  });
+
+  const cellLinks = {
+    'penultimate cell using heading, legacy format': 18,
+    'penultimate cell using heading, explicit fragment': 18,
+    'last cell using heading, legacy format': 19,
+    'last cell using heading, explicit fragment': 19,
+    'last cell using cell identifier': 19
+  };
+  for (const [link, cellIdx] of Object.entries(cellLinks)) {
+    test(`Scroll to ${link}`, async ({ page }) => {
+      const firstCellLocator = page.locator(
+        '.jp-Cell[data-windowed-list-index="0"]'
+      );
+      const lastCellLocator = page.locator(
+        `.jp-Cell[data-windowed-list-index="${cellIdx}"]`
+      );
+      await firstCellLocator.scrollIntoViewIfNeeded();
+
+      await page.click(`a:has-text("${link}")`);
+
+      await expect(firstCellLocator).not.toBeInViewport();
+      await expect(lastCellLocator).toBeInViewport();
+    });
+  }
+});
+
 test.describe('Notebook scroll on dragging cells (with windowing)', () => {
   test.beforeEach(async ({ page, tmpPath }) => {
     await page.contents.uploadFile(
@@ -118,7 +172,10 @@ test.describe('Notebook scroll on dragging cells (with windowing)', () => {
     await expect(lastCellLocator).toBeInViewport();
   });
 
-  test('Scroll up on dragging cell to the top edge', async ({ page }) => {
+  test('Scroll up on dragging cell to the top edge', async ({
+    page,
+    browserName
+  }) => {
     const firstCellLocator = page.locator(
       '.jp-Cell[data-windowed-list-index="0"]'
     );
@@ -142,7 +199,8 @@ test.describe('Notebook scroll on dragging cells (with windowing)', () => {
 
     // Ensure the notebook is scrolled correctly and first cell is not visible
     const before = await scroller.evaluate(node => node.scrollTop);
-    expect(before).toBeGreaterThan(notebookContentHeight * 0.75);
+    const factor = browserName === 'firefox' ? 0.6 : 0.75;
+    expect(before).toBeGreaterThan(notebookContentHeight * factor);
     await expect(firstCellLocator).not.toBeInViewport();
 
     // Emulate drag and drop
@@ -337,8 +395,10 @@ test.describe('Notebook scroll beyond a cell with long output (with windowing)',
   });
 
   test('should not change height of the scrollbar when scrolling beyond the cell long', async ({
-    page
+    page,
+    browserName
   }) => {
+    test.skip(browserName === 'firefox', 'Needs fixing on Firefox');
     // Make the first cell active
     await page.notebook.selectCells(0);
 
@@ -355,3 +415,68 @@ test.describe('Notebook scroll beyond a cell with long output (with windowing)',
     expect(scrollHeightBefore).toBeCloseTo(scrollHeightAfter);
   });
 });
+
+test.describe('Jump to execution button', () => {
+  test.use({
+    mockSettings: {
+      ...galata.DEFAULT_SETTINGS,
+      '@jupyterlab/notebook-extension:tracker': {
+        ...galata.DEFAULT_SETTINGS['@jupyterlab/notebook-extension:tracker'],
+        recordTiming: true,
+        kernelStatus: {
+          ...(galata.DEFAULT_SETTINGS['@jupyterlab/notebook-extension:tracker']
+            ?.kernelStatus ?? {}),
+          showJumpToRecentExecutionButton: true
+        }
+      }
+    }
+  });
+  test.beforeEach(async ({ page, tmpPath }) => {
+    await page.contents.uploadFile(
+      path.resolve(__dirname, `./notebooks/${longOutputsNb}`),
+      `${tmpPath}/${longOutputsNb}`
+    );
+
+    await page.notebook.openByPath(`${tmpPath}/${longOutputsNb}`);
+    await page.notebook.activate(longOutputsNb);
+  });
+  test('should show jump button after first execution and scroll to executing cells', async ({
+    page
+  }) => {
+    await page.notebook.setCell(0, 'code', 'from time import sleep\nsleep(2)');
+
+    // Button doesn't exist before execution
+    const indicator = page.locator('.jp-Notebook-ExecutionIndicator');
+    await indicator.hover();
+    await expect(
+      page.locator('.jp-Notebook-ExecutionIndicator-jumpButton')
+    ).toHaveCount(0);
+
+    // Run first cell
+    void page.notebook.runCell(0, false);
+
+    await page.notebook.addCell('code', '1');
+    const runPromise = page.notebook.runCell(3, false);
+
+    // Hover and verify button exists
+    await indicator.hover();
+    const jumpButton = page.locator(
+      '.jp-Notebook-ExecutionIndicator-jumpButton'
+    );
+    await expect(jumpButton).toBeVisible();
+
+    // Click and scroll to the first cell (currently executing)
+    await jumpButton.click();
+    const firstCell = await page.notebook.getCellLocator(0);
+    await firstCell?.waitFor({ state: 'visible', timeout: 1000 });
+
+    // Wait for all executions to complete
+    await runPromise;
+
+    // Click and scroll to last cell (last executed)
+    await indicator.hover();
+    await jumpButton.click();
+    const lastCell = await page.notebook.getCellLocator(3);
+    await lastCell?.waitFor({ state: 'visible', timeout: 1000 });
+  });
+});
