@@ -1,7 +1,12 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 
-import { expect, IJupyterLabPageFixture, test } from '@jupyterlab/galata';
+import {
+  expect,
+  galata,
+  IJupyterLabPageFixture,
+  test
+} from '@jupyterlab/galata';
 
 const fileName = 'notebook.ipynb';
 
@@ -69,6 +74,12 @@ async function addWidgetsInNotebookToolbar(
 }
 
 test.describe('Notebook Toolbar', () => {
+  test.use({
+    mockSettings: {
+      ...galata.DEFAULT_SETTINGS
+    }
+  });
+
   test.beforeEach(async ({ page }) => {
     await page.notebook.createNew(fileName);
     await populateNotebook(page);
@@ -155,6 +166,58 @@ test.describe('Notebook Toolbar', () => {
   });
 });
 
+test.describe('Notebook Toolbar using system clipboard', () => {
+  test.use({
+    mockSettings: {
+      ...galata.DEFAULT_SETTINGS,
+      '@jupyterlab/notebook-extension:tracker': {
+        useSystemClipboardForCells: true
+      }
+    }
+  });
+
+  test.beforeEach(async ({ page }) => {
+    await page.notebook.createNew(fileName);
+    await populateNotebook(page);
+  });
+
+  test('Copy-Paste cell', async ({ page }) => {
+    const imageName = 'copy-paste-cell.png';
+    await page.notebook.selectCells(2);
+    await page.notebook.clickToolbarItem('copy');
+    await page.notebook.selectCells(0);
+    await page.notebook.clickToolbarItem('paste');
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
+
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
+  });
+
+  test('Cut cell', async ({ page }) => {
+    const imageName = 'cut-cell.png';
+    await page.notebook.selectCells(1);
+    await page.notebook.clickToolbarItem('cut');
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
+
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
+  });
+
+  test('Paste cell', async ({ page }) => {
+    // Cut cell to populate clipboard
+    await page.notebook.selectCells(0);
+    await page.notebook.clickToolbarItem('cut');
+
+    const imageName = 'paste-cell.png';
+    await page.notebook.selectCells(1);
+    await page.notebook.clickToolbarItem('paste');
+    const nbPanel = await page.notebook.getNotebookInPanelLocator();
+
+    await expect(
+      page.locator('.jp-Notebook-cell.jp-mod-active .jp-cell-toolbar')
+    ).toBeVisible();
+    expect(await nbPanel!.screenshot()).toMatchSnapshot(imageName);
+  });
+});
+
 test('Toolbar items act on owner widget', async ({ page }) => {
   // Given two side-by-side notebooks and the second being active
   const file1 = 'notebook1.ipynb';
